import 'package:flutter/material.dart';
import 'package:flutter_custom_toolbox/flutter_toolbox.dart';

import 'package:random/config/default_activity_settings.dart';
import 'package:random/models/settings/settings_activity.dart';

part 'settings_activity_state.dart';

class ActivitySettingsCubit extends HydratedCubit<ActivitySettingsState> {
  ActivitySettingsCubit()
      : super(ActivitySettingsState(settings: ActivitySettings.createDefault()));

  void setValues({
    String? itemsCount,
    String? timerValue,
  }) {
    emit(
      ActivitySettingsState(
        settings: ActivitySettings(
          boardSize: itemsCount ?? state.settings.boardSize,
          colorsCount: timerValue ?? state.settings.colorsCount,
        ),
      ),
    );
  }

  String getParameterValue(String code) {
    switch (code) {
      case DefaultActivitySettings.parameterCodeBoardSize:
        return ActivitySettings.getItemsCountValueFromUnsafe(state.settings.boardSize);
      case DefaultActivitySettings.parameterCodeColorsCount:
        return ActivitySettings.getTimerValueFromUnsafe(state.settings.colorsCount);
    }

    return '';
  }

  void setParameterValue(String code, String value) {
    final String itemsCount = code == DefaultActivitySettings.parameterCodeBoardSize
        ? value
        : getParameterValue(DefaultActivitySettings.parameterCodeBoardSize);
    final String timerValue = code == DefaultActivitySettings.parameterCodeColorsCount
        ? value
        : getParameterValue(DefaultActivitySettings.parameterCodeColorsCount);

    setValues(
      itemsCount: itemsCount,
      timerValue: timerValue,
    );
  }

  @override
  ActivitySettingsState? fromJson(Map<String, dynamic> json) {
    final String itemsCount = json[DefaultActivitySettings.parameterCodeBoardSize] as String;
    final String timerValue = json[DefaultActivitySettings.parameterCodeColorsCount] as String;

    return ActivitySettingsState(
      settings: ActivitySettings(
        boardSize: itemsCount,
        colorsCount: timerValue,
      ),
    );
  }

  @override
  Map<String, dynamic>? toJson(ActivitySettingsState state) {
    return <String, dynamic>{
      DefaultActivitySettings.parameterCodeBoardSize: state.settings.boardSize,
      DefaultActivitySettings.parameterCodeColorsCount: state.settings.colorsCount,
    };
  }
}
